.. include:: globals.rst

============
Introduction
============

This library is published as support for MKVBatchMultiplex_ development and
anything else I release.  It became to complicated to maintain the library
private and only pull what I need with each applications. This started to
require to much effort and some time had to do back ports to fixes. There
are many functions and classes not bound to a particular application that
will be documented over time.

Everything is as is there is no warranty that the library is fit for any
particular use.
